package simplegridtestng;

import dotn_helper.DOTN_Helper;
import dotn_helper.LoginAndLogoff;
import java.util.logging.Level;
import java.util.logging.Logger;
import static org.testng.Assert.*;
import org.testng.Reporter;
import org.testng.annotations.*;

/**
 * This class handles testing that login and logoff are working properly.
 * @author mriley
 */
public class DOTN_LoginTest
{
    /**
     * This is what we use to run the login test.
     */
    private LoginAndLogoff loginTest = null;
    /**
     * Selenium task for this test.
     */
    private DOTN_Helper helper;

    /**
     * setUp is used to start the Selenium session and also to gather a copy of
     * all the parameters we parsed from the command line.  It seems that the
     * way the tests are invoked by the testng.run() method creates a new
     * instance of the class, so even if you extend the class your main() is in
     * you do not have access to any of the variables from it.
     * @param url This is from the parameter selenium.url in the XML file.
     * @param browserString This is from the selenium.browser in the XML file.
     */
    @BeforeTest(groups = ("Login & Logout"))
    @Parameters(
    {
        "selenium.url", "selenium.browser"
    })
    public void setUp(String url, String browserString)
    {
        final String unableToStartSession = "Unable to create Selenium session.";

        try
        {
            Reporter.log("Creating Selenium " + browserString + " " + url +
                         " session...", true);
            helper = new DOTN_Helper(SimpleGridTestNG.testParams);
            loginTest = new LoginAndLogoff(helper);
        }
        catch (Throwable ex)
        {   // Log this to the console.  It gets put into the report for us.
            SimpleGridTestNG.passed = false;
            if (helper != null)
                helper.logException(unableToStartSession, ex);
            else
            {   // Since we don't have a DOTN_Helper instance we do this ourselves
                Reporter.log(unableToStartSession, true);
                Logger.getLogger(DOTN_LoginTest.class.getName()).log(
                        Level.SEVERE, null, ex); // Insure it is displayed
                Reporter.log(DOTN_Helper.throwableToString(ex) + "<br />", true);
            }

            assertFalse(true, ex.getMessage()); // Show that the test failed
        }
    }   // setUp()

    /**
     * This is the routine that actually fires off the requested loginTest.
     * @param serialNumber Is the serial number to use for logging in to DOTN.
     * @param userName Is the user name to use for logging in to DOTN.
     * @param password Is the password to use for logging in to DOTN.
     */
    @Parameters(
    {
        "dotn.serial", "dotn.username", "dotn.password"
    })
    @Test(suiteName = "SimpleGridTestNG",
          groups = ("Login & Logout"),
          description = "Login test",
          singleThreaded = true)
    public void loginTest(String serialNumber, String userName,
                          String password)
    {
        try
        {   // Try to logon to DOTN
            Reporter.log("Trying to login to DOTN...", true);
            loginTest.testLogin(serialNumber, userName, password);
            assertTrue(true); // Show that the test passed
        }
        catch (Throwable ex)
        {   // Show that the test failed
            SimpleGridTestNG.passed = false;
            helper.logException("Unable to login using " + serialNumber +
                                " / " + userName + " / " + password, ex);
            assertTrue(false, ex.getMessage());
        }
    }   // loginTest()

    /**
     * This is the routine that fires off the required logout test.
     */
    @Test(suiteName = "SimpleGridTestNG",
          groups = ("Login & Logout"),
          dependsOnMethods = "loginTest",
          description = "Logout test",
          singleThreaded = true)
    public void logoutTest()
    {
        try
        {   // Now try to logout of DOTN
            Reporter.log("Logging off DOTN", true);
            loginTest.testLogout();
            helper.logException("Logout worked!", null);
            assertTrue(true); // Show that the test passed
        }
        catch (Throwable ex)
        {   // Show that the test failed
            SimpleGridTestNG.passed = false;
            helper.logException("Unable to logout after login in succeeded.",
                                ex);
            assertTrue(false, ex.getMessage());
        }
    }   // logoutTest()

    /**
     * When the class is finished do any cleanup here.
     * @throws Exception
     */
    @AfterTest(groups = ("Login & Logout"))
    public void tearDown() throws Exception
    {
        helper.tearDown();
    }   // tearDown()
}
