/**
 * simplegridtestng Is the package used to test that we can run through the grid
 * and execute tests.  Right now it simply verifies that we can login and logoff
 * the DOTN web site.
 */
package simplegridtestng;

import dotn_helper.TestParameters;
import java.util.logging.Level;
import java.util.logging.Logger;
import libJava.Parser;
import org.testng.TestNG;

/**
 * Class SimpleGridTestNG uses the TestNG framework and the Selenium Web
 * Driver interface to do a loginTest through the grid server.
 * @author mriley
 */
public class SimpleGridTestNG
{
    /**
     * This is an instance of the libJava parser that we use for parsing command
     * line options.
     */
    public static Parser parser;
    /**
     * This is a public copy of the test parameters we are using to run with. It
     * is initialized using the default constructor, so additional parameters
     * for a specific test utility should be added using addTestParameters().
     */
    public static TestParameters testParams;
    /**
     * This flag is used to determine if the tests all passed.  It defaults to
     * true, so any test that fails can set it to false to show that something
     * in the test series has failed.  If a test fails we return a non-zero exit
     * code back to the invoking program (usually to a shell).
     */
    public static boolean passed = true;
    /**
     * This is the list of tests that we support by default.
     */
    private static final String[] testClasses =
    {
        "simplegridtestng.DOTN_LoginTest"
    };

    /**
     * main is used to gather the parameters needed at run time.  It then will
     * create the necessary XML file to run the tests and start the TestNG, just
     * as it does when you invoke it from within the IDE.
     * Look at @see <a href="http://testng.org/doc/documentation-main.html#running-testng-programmatically">Running TestNG programmatically</a>
     * @param args The command line arguments: < <-t TestName> <-b BrowserName>
     * <-u TestURL> <-s SerialNumber> <-n UserName> <-p Password>
     * <-r ReportDirectory | <-h> >
     * The -h switch is for help and causes all other switches to be ignored.
     * Later on we might need to add a switch to specify the host and/or port.
     */
    public static void main(String[] args)
    {
        TestNG testng = new TestNG();

        testParams = new TestParameters(args);
        testParams.setupTestXmlFile(testng);
        try
        {
            testParams.setupSuite("SimpleGridTestNG"); // The name of the suite
            testParams.addTest("Login & Logout", testClasses); // The group and its classes
            testParams.addSuite(); // Add the suite to the TestNG instance
            testParams.finalizeTestXmlFile(); // The TestNG XML file is complete
            testng.run();   // Kick off the selected tests for this browser
            if (passed)
                System.exit(0); // All tests passed!
            else
                System.exit(1); // Some test(s) failed...
        }
        catch (Exception ex)
        {
            Logger.getLogger(SimpleGridTestNG.class.getName()).
                    log(Level.SEVERE, null, ex);
        }
    }   // main

    /**
     * SimpleGridTestNG is a private constructor to stop Netbeans from nagging
     * about it being missing.
     */
    private SimpleGridTestNG()
    {
    }   // SimpleGridTestNG
}